use Test::More;

use_ok('App::financeta::mo');
use_ok('App::financeta::indicators');
use_ok('App::financeta::editor');
use_ok('App::financeta::gui');
use_ok('App::financeta');

done_testing();

__END__
### COPYRIGHT: 2014 Vikas N. Kumar. All Rights Reserved.
### AUTHOR: Vikas N Kumar <vikas@cpan.org>
### DATE: 15th Aug 2014
### LICENSE: Refer LICENSE file

